# #################################################
#
#  This file contains an example driver file for 
#    the 2D heat conduction class, and uses the
#    python 'time' module to calculate time used per
#    timestep.
#
#  Written by Brian O'Shea (oshea@msu.edu)
#
# #################################################

from HeatConduction2D import HeatConduction2D
from time import clock

# instantiate an instance of the class
heat = HeatConduction2D()

# Create initial conditions (gausssian pulse)
# This example creates a Gaussian pulse.
heat.create_initial_conditions(ic_type=1, background_temp = 10.0, peak_temp = 1000.0, pulse_fwhm=1.0)

# This example creates a set of sine waves (4, to be exact)
#heat.create_initial_conditions(ic_type=2, background_temp = 2.0, peak_temp = 6.0, number_of_waves=4)

# USER SETS THESE PARAMETERS
simulation_stop_time = 2.0
image_output_every_Nth_timestep = 2

start_walltime = clock()

iter = 0
image_number = 0
this_time = 0.0

# simulation start time.
while this_time < simulation_stop_time:
    
    t1 = clock()

    # advance simulation one timestep.
    this_dt = heat.advance_simulation()

    # write an output file.
    if iter % image_output_every_Nth_timestep == 0:
        heat.write_output_file("file%04d.png" % image_number, colormap="hot")
        print "wrote data output:", iter, "image number", image_number
        image_number += 1
        
    t2 = clock()


    iter += 1
    this_time += this_dt

    print "iter:", iter, "dt:", this_dt, "time:", this_time, "wallclock delta_t:", t2-t1 

end_walltime = clock()

print "total simulation time is", end_walltime - start_walltime, \
      "seconds with a mean time per timestep of", (end_walltime-start_walltime)/iter, \
      "seconds with", iter, "total timesteps"
